@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.64 2006/07/17 13:47:59 evertonm Exp $ */
+/* $Id: client.c,v 1.67 2006/08/14 20:20:11 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -675,10 +675,12 @@ static void tcp_pipe_start(int sd)
   else {
     if (session->keepalive_must_send) {
 
+#if 0
       fprintf(stderr, 
               "DEBUG %s %s: %d: scheduling sending of keepalives\n",
               __FILE__, __PRETTY_FUNCTION__,
               sd);
+#endif
       
       session->tv_keepalive_send_next = OOP_TIME_NOW;
       nepim_global.oop_src->on_time(nepim_global.oop_src,
@@ -803,7 +805,8 @@ static void tcp_pipe_stop(int sd)
   nepim_sock_show_opt(nepim_global.verbose_stderr, stderr, sd);
 }
 
-static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
+static void spawn_one_tcp_client(const char *hostport,
+				 const struct sockaddr *bindaddr,
 				 int bindaddr_len,
 				 const char *hostname,
 				 const char *portname)
@@ -819,10 +822,10 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
   memset(&hints, 0, sizeof(hints));
 
   if (nepim_global.search_unix_socket) {
-    gai_lookup = stat(hostname, &stat_buf);
+    gai_lookup = stat(hostport, &stat_buf);
     if (gai_lookup)
       fprintf(stderr, "not a UNIX domain path: %s: errno=%d: %s\n",
-	      hostname, errno, strerror(errno));
+	      hostport, errno, strerror(errno));
   }
   else
     gai_lookup = -1;
@@ -858,7 +861,7 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
       Unix socket
      */
 
-    int len = strlen(hostname);
+    int len = strlen(hostport);
     if (len >= (int) sizeof(un_sock_addr.sun_path)) {
       fprintf(stderr, "%s %s: unix socket path overly long: len=%d > max=%d\n",
 	      __FILE__, __PRETTY_FUNCTION__,
@@ -869,7 +872,7 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
     memset(&un_sock_addr, 0, sizeof(un_sock_addr));
 
     un_sock_addr.sun_family = AF_UNIX;
-    strcpy(un_sock_addr.sun_path, hostname);
+    strcpy(un_sock_addr.sun_path, hostport);
 
     hints.ai_socktype = SOCK_STREAM;
     hints.ai_protocol = 0;
@@ -892,7 +895,7 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
     if (ai->ai_family == PF_UNIX)
       fprintf(stderr, 
 	      "UNIX stream socket trying path=%s\n",
-	      hostname);
+	      hostport);
     else
       fprintf(stderr, 
 	      "TCP socket trying %s,%d\n",
@@ -922,7 +925,7 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
       if (ai->ai_family == AF_UNIX)
 	fprintf(stderr, 
 		"could not connect UNIX stream socket to path=%s: %d\n",
-		hostname, sd);
+		hostport, sd);
       else
 	fprintf(stderr, 
 		"could not connect TCP socket to %s,%d: %d\n",
@@ -934,7 +937,7 @@ static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
     if (ai->ai_family == AF_UNIX)
       fprintf(stderr, 
 	      "%d: UNIX stream socket connected to path=%s\n",
-	      sd, hostname); 
+	      sd, hostport); 
     else
       fprintf(stderr, 
 	      "%d: TCP socket connected to %s,%d\n",
@@ -995,6 +998,7 @@ static void parse_hosts(const char *host_list)
 
   /* scan host_list */
   for (j = 0; j < size; ++j) {
+    char hostport[100];
     char hostname[100];
     char *portname;
 
@@ -1006,13 +1010,16 @@ static void parse_hosts(const char *host_list)
       continue;
     }
 
+    strcpy(hostport, hostname); /* save original "host,port" */
+
     /* split host/port */
     if (addr_split_port(hostname, sizeof(hostname), &portname))
       portname = (char *) nepim_global.portname;
 
     /* create sockets */
     for (i = 0; i < nepim_global.pipes; ++i)
-      spawn_one_tcp_client(bind_addr, bind_addr_len,
+      spawn_one_tcp_client(hostport,
+			   bind_addr, bind_addr_len,
 			   hostname, portname);
 
   } /* scan host_list */
