@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.79 2006/07/17 21:38:49 evertonm Exp $ */
+/* $Id: common.c,v 1.81 2006/08/15 13:20:33 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,7 +47,7 @@ static int line = 0;
 
 const char *nepim_version()
 {
-  return "0.35";
+  return "0.36";
 }
 
 static void header(FILE *out, int ident, int udp)
@@ -57,8 +57,11 @@ static void header(FILE *out, int ident, int udp)
       putc(' ', out);
     fprintf(out, " %10s %10s %8s %8s", 
 	    "kbps_in", "kbps_out", "rcv/s", "snd/s");
-    if (udp)
+    if (udp) {
       fprintf(out, " %5s %5s", "loss", "ooo");
+      if (nepim_global.udp_accumulative_loss)
+	fprintf(out, " %s", "LOST");
+    }
     fprintf(out, "\n");
   }
 }
@@ -111,7 +114,8 @@ void nepim_slot_stat(FILE *out, struct timeval now,
                      long long bytes_recv, long long bytes_sent, 
                      float interval, long sec_start, 
                      long sec_duration, int reads, int writes,
-                     uint64_t pkt_expected, uint64_t pkt_lost, uint64_t pkt_ooo)
+                     uint64_t pkt_expected, uint64_t pkt_lost,
+		     uint64_t pkt_ooo, uint64_t acc_pkt_lost)
 {
   char buf[100];
   int pr;
@@ -154,6 +158,9 @@ void nepim_slot_stat(FILE *out, struct timeval now,
     fprintf(out, " %s", (*buf == '0') ? (buf + 1) : buf);
   }
 
+  if (nepim_global.udp_accumulative_loss)
+    fprintf(out, " %llu", acc_pkt_lost);
+
   fprintf(out, "\n");
 
   /* otherwise server won't output stats if out is redirected */
@@ -228,7 +235,8 @@ void report_broken_slot_stat_at(FILE *out, nepim_slot_t *slot,
                   session->total_writes,
 		  slot->seq_highest_recv,
                   slot->total_pkt_lost,
-                  slot->total_pkt_ooo);
+                  slot->total_pkt_ooo,
+		  slot->total_pkt_lost);
 }
 
 void report_broken_slot_stat(FILE *out, nepim_slot_t *slot)
