@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: greet.c,v 1.15 2006/04/23 06:33:46 evertonm Exp $ */
+/* $Id: greet.c,v 1.18 2006/06/02 14:24:38 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -45,6 +45,10 @@ const char *GREET_PAUSE_DURATION    = "pause_duration=";
 const char *GREET_SOCKET_KEEPALIVE  = "sock_ka=";
 const char *GREET_NAGLE             = "nagle=";
 const char *GREET_OVERHEAD          = "overhead=";
+const char *GREET_SWEEP_RANDOM      = "sweep_random=";
+const char *GREET_SWEEP_STEP        = "sweep_step=";
+const char *GREET_WRITE_FLOOR       = "write_floor=";
+const char *GREET_WRITE_CEIL        = "write_ceil=";
 const char *GREET_PASSWORD          = "password=";
 
 #define NEPIM_GREET_PARSE_OK     (0)
@@ -71,7 +75,9 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
                 " %s%d %s%d %s%d"
                 " %s%ld %s%d %s%d"
 		" %s0x%08x %s%d %s%d %s0x%02x %s%d"
-		" %s%d %s%d %s%d %s%s\n", 
+		" %s%d %s%d %s%d"
+		" %s%d %s%d %s%d %s%d"
+		" %s%s\n", 
                 GREET_SERVER_SEND,       opt->must_send,
                 GREET_BIT_RATE,          opt->bit_rate,
                 GREET_PKT_RATE,          opt->pkt_rate,
@@ -88,6 +94,10 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
                 GREET_SOCKET_KEEPALIVE,  opt->socket_keepalive,
                 GREET_NAGLE,             opt->nagle,
 		GREET_OVERHEAD,          opt->overhead,
+		GREET_SWEEP_RANDOM,      opt->sweep_random,
+		GREET_SWEEP_STEP,        opt->sweep_step,
+		GREET_WRITE_FLOOR,       opt->write_floor,
+		GREET_WRITE_CEIL,        opt->write_ceil,
                 GREET_PASSWORD,          opt->password_buf);
 
   if (pr < 1)
@@ -125,6 +135,10 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   const int GREET_SOCKET_KEEPALIVE_LEN  = strlen(GREET_SOCKET_KEEPALIVE);
   const int GREET_NAGLE_LEN             = strlen(GREET_NAGLE);
   const int GREET_OVERHEAD_LEN          = strlen(GREET_OVERHEAD);
+  const int GREET_SWEEP_RANDOM_LEN      = strlen(GREET_SWEEP_RANDOM);
+  const int GREET_SWEEP_STEP_LEN        = strlen(GREET_SWEEP_STEP);
+  const int GREET_WRITE_FLOOR_LEN       = strlen(GREET_WRITE_FLOOR);
+  const int GREET_WRITE_CEIL_LEN        = strlen(GREET_WRITE_CEIL);
   const int GREET_PASSWORD_LEN          = strlen(GREET_PASSWORD);
 
   int       server_send       = -2;
@@ -143,6 +157,10 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   int       socket_keepalive  = -2;
   int       nagle             = -2;
   int       overhead          = -2;
+  int       sweep_random      = -2;
+  int       sweep_step        = -55555; /* something obviously wrong (-2 is too sane) */
+  int       write_floor       = -2;
+  int       write_ceil        = -2;
 
   assert(opt->password_buf);
   assert(opt->password_buf_size > 0);
@@ -252,6 +270,26 @@ int nepim_parse_greetings(nepim_greet_t *opt,
       continue;
     }
 
+    if (!strncmp(tok, GREET_SWEEP_RANDOM, GREET_SWEEP_RANDOM_LEN)) {
+      sweep_random = atoi(tok + GREET_SWEEP_RANDOM_LEN);
+      continue;
+    }
+
+    if (!strncmp(tok, GREET_SWEEP_STEP, GREET_SWEEP_STEP_LEN)) {
+      sweep_step = atoi(tok + GREET_SWEEP_STEP_LEN);
+      continue;
+    }
+
+    if (!strncmp(tok, GREET_WRITE_FLOOR, GREET_WRITE_FLOOR_LEN)) {
+      write_floor = atoi(tok + GREET_WRITE_FLOOR_LEN);
+      continue;
+    }
+
+    if (!strncmp(tok, GREET_WRITE_CEIL, GREET_WRITE_CEIL_LEN)) {
+      write_ceil = atoi(tok + GREET_WRITE_CEIL_LEN);
+      continue;
+    }
+
     if (!strncmp(tok, GREET_PASSWORD, GREET_PASSWORD_LEN)) {
       const char *tmp_past_end = tmp + sizeof(tmp);
       const char *pass;
@@ -310,6 +348,10 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   opt->socket_keepalive    = socket_keepalive;
   opt->nagle               = nagle;
   opt->overhead            = overhead;
+  opt->sweep_random        = sweep_random;
+  opt->sweep_step          = sweep_step;
+  opt->write_floor         = write_floor;
+  opt->write_ceil          = write_ceil;
 
   return NEPIM_GREET_PARSE_OK;
 }
