@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.62 2006/06/14 17:36:34 evertonm Exp $
+  $Id: main.c,v 1.63 2006/08/15 13:20:33 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -106,6 +106,7 @@ static void usage(FILE *out, const char *prog_name)
 	  "  -Q             quietly hide debug errors\n"
 	  "  -y tos         ip tos (defaults to %d, tos=-1 means don't change)\n"
 	  "  -K udp-ka-time UDP keepalive timeout (defaults to %ld us)\n"
+	  "  -L             supress output of UDP accumulative loss\n"
 	  "\n"
           "client-only options:\n"
           "  -u             UDP mode (defaults to TCP)\n"
@@ -371,6 +372,11 @@ int main(int argc, const char *argv[])
       continue;
     }
 
+    if (!strcmp(arg, "-L")) {
+      nepim_global.udp_accumulative_loss = 0;
+      continue;
+    }
+
     if (!strcmp(arg, "-q")) {
       nepim_global.soft_error_verbose = 0;
       continue;
