@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: slot.h,v 1.25 2006/04/18 12:10:15 evertonm Exp $ */
+/* $Id: slot.h,v 1.29 2006/05/11 12:23:35 evertonm Exp $ */
 
 #ifndef NEPIM_SLOT_H
 #define NEPIM_SLOT_H
@@ -27,7 +27,6 @@ MA 02110-1301 USA
 
 #include "array.h"
 #include "session.h"
-#include "win.h"
 
 typedef struct nepim_slot_t nepim_slot_t;
 typedef struct nepim_slot_set_t nepim_slot_set_t;
@@ -38,21 +37,23 @@ enum {
 };
 
 struct nepim_slot_t {
-  int             index;        /* self indexing */
-  int             index_remote; /* remote indexing */
-  int             udp_sd;       /* udp socket */
-  uint32_t        seq;          /* udp sequence number */
+  int             index;                     /* self indexing */
+  int             index_remote;              /* remote indexing */
+  int             udp_sd;                    /* udp socket */
+  uint64_t        seq;                       /* udp sequence number */
+  uint64_t        seq_highest_recv;
   nepim_session_t session;
-  int             want_write;           /* boolean */
-  int             greetings_sent;       /* counter */
-  int             client_writer_status; /* greet/send */
-  nepim_win_t     win_recv_seq;
+  int             want_write;                /* boolean */
+  int             greetings_sent;            /* counter */
+  int             client_writer_status;      /* greet/send */
+  uint64_t        interval_last_highest_seq;
+  int             interval_pkt_recv;
   int             interval_pkt_lost;
-  int             interval_pkt_dup;
-  int             total_pkt_lost;
-  int             total_pkt_dup;
-  int             exp_loss_sampler;
-  int             exp_dup_sampler;
+  int             interval_pkt_ooo;          /* out-of-order */
+  uint64_t        subtotal_pkt_lost;         /* lost until last interval */
+  uint64_t        total_pkt_lost;
+  uint64_t        total_pkt_recv;
+  uint64_t        total_pkt_ooo;             /* out-of-order */
 };
 
 struct nepim_slot_set_t {
@@ -87,6 +88,10 @@ int nepim_slot_find_addr(const nepim_slot_set_t *set,
 int nepim_slot_buf_sendto(nepim_slot_t *slot, char *buf, size_t buf_size, uint8_t type);
 int nepim_slot_buf_write(nepim_slot_t *slot, char *buf, size_t buf_size, uint8_t type);
 
+void nepim_slot_seq_recv(nepim_slot_t *slot, uint64_t seq);
+
+void nepim_slot_update_pkt_stat(nepim_slot_t *slot);
+
 /*
  * this is a (exceedingly?) complex way of reusing
  * code between udp_server.c and udp_client.c 
