@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: sock.c,v 1.37 2006/05/12 19:14:26 evertonm Exp $ */
+/* $Id: sock.c,v 1.41 2006/06/07 15:27:43 evertonm Exp $ */
 
 #include <assert.h>
 #include <netdb.h>
@@ -271,33 +271,91 @@ static int socket_set_win_send(int sd, int win_send)
   return NEPIM_SOCK_ERR_NONE;
 }
 
-int nepim_socket_tos(int sd, int tos)
+int nepim_socket_tos(FILE *err, int sd, int tos)
 {
   if (tos < 0)
     return NEPIM_SOCK_ERR_NONE;
 
-  return setsockopt(sd, SOL_IP, IP_TOS, &tos, sizeof(tos));
+  if (setsockopt(sd, SOL_IP, IP_TOS, &tos, sizeof(tos))) {
+
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: setsockopt: tos=%d (0x%02x): sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      tos, tos, sd, e, strerror(e));
+    }
+
+    return NEPIM_SOCK_ERR_TOS;
+  }
+
+  return NEPIM_SOCK_ERR_NONE;
 }
 
-static int create_socket(int domain, int type, int protocol, int pmtu_mode, int ttl,
-			 int win_recv, int win_send, int nodelay, int tos)
+static const char *family_name(int family)
+{
+  switch (family) {
+  case AF_INET:
+    return "inet";
+  case AF_INET6:
+    return "inet6";
+  }
+
+  return "unknown_family";
+}
+
+static const char *socket_type_name(int type)
+{
+  switch (type) {
+  case SOCK_STREAM:
+    return "stream";
+  case SOCK_DGRAM:
+    return "datagram";
+  }
+
+  return "unknown_socket_type";
+}
+
+static const char *proto_name(int proto)
+{
+  struct protoent *pe;
+
+  pe = getprotobynumber(proto);
+  if (pe)
+    return pe->p_name;
+
+  return "unknown_protocol";
+}
+
+static int create_socket(FILE *err, int domain, int type, int protocol,
+			 int pmtu_mode, int ttl, int win_recv,
+			 int win_send, int nodelay, int tos)
 {
   int sd;
   int result;
 
   sd = socket(domain, type, protocol);
-  if (sd < 0)
+  if (sd < 0) {
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: socket(%s,%s,%s): errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      family_name(domain), socket_type_name(type),
+	      proto_name(protocol),
+	      e, strerror(e));
+    }
+
     return NEPIM_SOCK_ERR_SOCKET;
+  }
 
   if (type == SOCK_STREAM) {
-    result = nepim_socket_tcp_opt(domain, sd, nodelay);
+    result = nepim_socket_tcp_opt(err, domain, sd, nodelay);
     if (result) {
       close(sd);
       return result;
     }
   }
 
-  result = nepim_socket_opt(sd, pmtu_mode, ttl, tos);
+  result = nepim_socket_opt(err, sd, pmtu_mode, ttl, tos);
   if (result) {
     close(sd);
     return result;
@@ -361,7 +419,8 @@ static int socket_mcast_join(int sd, int family,
   return NEPIM_SOCK_ERR_MCAST_JOIN;
 }
 
-int nepim_create_socket(const struct sockaddr *addr, int addr_len,
+int nepim_create_socket(FILE *err,
+			const struct sockaddr *addr, int addr_len,
 			int family,
 			int type,
 			int protocol,
@@ -376,7 +435,7 @@ int nepim_create_socket(const struct sockaddr *addr, int addr_len,
   int sd;
   int result;
 
-  sd = create_socket(family, type, protocol, pmtu_mode, ttl,
+  sd = create_socket(err, family, type, protocol, pmtu_mode, ttl,
 		     win_recv, win_send, nodelay, tos);
   if (sd < 0)
     return sd;
@@ -386,15 +445,18 @@ int nepim_create_socket(const struct sockaddr *addr, int addr_len,
     assert(protocol == IPPROTO_UDP);
     
     if (socket_mcast_join(sd, family, addr, addr_len)) {
-      char buf[500];
-      int e = errno;
 
-      nepim_sock_dump_addr(buf, sizeof(buf), addr, addr_len);
+      if (err) {
+	char buf[500];
+	int e = errno;
 
-      fprintf(stderr, "%s: %s: mcast_join(%d,%s,%d): errno=%d: %s\n",
-	      __FILE__, __PRETTY_FUNCTION__,
-	      sd, buf, nepim_sock_get_port(addr),
-	      e, strerror(e));
+	nepim_sock_dump_addr(buf, sizeof(buf), addr, addr_len);
+
+	fprintf(err, "%s: %s: mcast_join(%d,%s,%d): errno=%d: %s\n",
+		__FILE__, __PRETTY_FUNCTION__,
+		sd, buf, nepim_sock_get_port(addr),
+		e, strerror(e));
+      }
 
       close(sd);
       return NEPIM_SOCK_ERR_MCAST_JOIN;
@@ -411,22 +473,25 @@ int nepim_create_socket(const struct sockaddr *addr, int addr_len,
     return sd;
 
   if (bind(sd, addr, addr_len)) {
-    char buf[500];
-    int e = errno;
 
-    nepim_sock_dump_addr(buf, sizeof(buf), addr, addr_len);
-
-    if (family == AF_UNIX)
-      fprintf(stderr, "%s: %s: UNIX-socket bind(%d,%s): errno=%d: %s\n",
-	      __FILE__, __PRETTY_FUNCTION__,
-	      sd, buf,
-	      e, strerror(e));
+    if (err) {
+      char buf[500];
+      int e = errno;
+      
+      nepim_sock_dump_addr(buf, sizeof(buf), addr, addr_len);
+      
+      if (family == AF_UNIX)
+	fprintf(err, "%s: %s: UNIX-socket bind(%d,%s): errno=%d: %s\n",
+		__FILE__, __PRETTY_FUNCTION__,
+		sd, buf,
+		e, strerror(e));
       else
-	fprintf(stderr, "%s: %s: bind(%d,%s,%d): errno=%d: %s\n",
+	fprintf(err, "%s: %s: bind(%d,%s,%d): errno=%d: %s\n",
 		__FILE__, __PRETTY_FUNCTION__,
 		sd, buf, nepim_sock_get_port(addr),
 		e, strerror(e));
-
+    }
+    
     close(sd);
     return NEPIM_SOCK_ERR_BIND;
   }
@@ -434,7 +499,8 @@ int nepim_create_socket(const struct sockaddr *addr, int addr_len,
   return sd;
 }
 
-int nepim_create_listener_socket(struct sockaddr *addr,
+int nepim_create_listener_socket(FILE *err,
+				 struct sockaddr *addr,
 				 int addr_len,
 				 int family,
 				 int type,
@@ -449,7 +515,7 @@ int nepim_create_listener_socket(struct sockaddr *addr,
 {
   int sd;
 
-  sd = nepim_create_socket(addr, addr_len, family,
+  sd = nepim_create_socket(err, addr, addr_len, family,
 			   type, protocol, pmtu_mode, 
 			   ttl, 0, win_recv, win_send,
 			   nodelay, tos);
@@ -457,7 +523,16 @@ int nepim_create_listener_socket(struct sockaddr *addr,
     return sd;
 
   if (listen(sd, backlog)) {
+
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: listen: sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      sd, e, strerror(e));
+    }
+
     close(sd);
+
     return NEPIM_SOCK_ERR_LISTEN;
   }
 
@@ -481,17 +556,19 @@ static int reuse(int sd)
   return setsockopt(sd, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(opt));
 }
 
-static int set_tcp_nodelay(int sd, int nodelay)
+static int set_tcp_nodelay(FILE *err, int sd, int nodelay)
 {
   if (nodelay == -1)
     return NEPIM_SOCK_ERR_NONE;
 
   if (setsockopt(sd, SOL_TCP, TCP_NODELAY,
 		 &nodelay, sizeof(nodelay))) {
-    int e = errno;
-    fprintf(stderr, "%s: %s: set socket TCP_NODELAY: sd=%d: errno=%d: %s\n",
-	    __FILE__, __PRETTY_FUNCTION__,
-	    sd, e, strerror(e));
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: setsockopt: TCP_NODELAY: sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      sd, e, strerror(e));
+    }
 
     return NEPIM_SOCK_ERR_NODELAY;
   }
@@ -499,19 +576,19 @@ static int set_tcp_nodelay(int sd, int nodelay)
   return NEPIM_SOCK_ERR_NONE;
 }
 
-static int nepim_socket_get_nodelay(int sd)
+static int nepim_socket_get_nodelay(FILE *err, int sd)
 {
   int nodelay;
   socklen_t optlen = sizeof(nodelay);
 
   if (getsockopt(sd, SOL_TCP, TCP_NODELAY,
 		 &nodelay, &optlen)) {
-#if 0
-    int e = errno;
-    fprintf(stderr, "%s: %s: get socket TCP_NODELAY: sd=%d: errno=%d: %s\n",
-	    __FILE__, __PRETTY_FUNCTION__,
-	    sd, e, strerror(e));
-#endif
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: getsockopt: TCP_NODELAY: sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      sd, e, strerror(e));
+    }
 
     return NEPIM_SOCK_ERR_NODELAY;
   }
@@ -521,7 +598,7 @@ static int nepim_socket_get_nodelay(int sd)
   return nodelay;
 }
 
-int nepim_socket_opt(int sd, int pmtu_mode, int ttl, int tos)
+int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos)
 {
   if (unlinger(sd))
     return NEPIM_SOCK_ERR_UNLINGER;
@@ -535,15 +612,15 @@ int nepim_socket_opt(int sd, int pmtu_mode, int ttl, int tos)
   if (nepim_socket_ttl(sd, ttl))
     return NEPIM_SOCK_ERR_TTL;
 
-  if (nepim_socket_tos(sd, tos))
+  if (nepim_socket_tos(err, sd, tos))
     return NEPIM_SOCK_ERR_TOS;
 
   return NEPIM_SOCK_ERR_NONE;
 }
 
-int nepim_socket_tcp_opt(int family, int sd, int nodelay)
+int nepim_socket_tcp_opt(FILE *err, int family, int sd, int nodelay)
 {
-  if (set_tcp_nodelay(sd, nodelay)) {
+  if (set_tcp_nodelay(err, sd, nodelay)) {
     /*
       Tolerate failure in setting NODELAY for PF_UNIX sockets
     */
@@ -554,34 +631,42 @@ int nepim_socket_tcp_opt(int family, int sd, int nodelay)
   return NEPIM_SOCK_ERR_NONE;
 }
 
-int nepim_socket_keepalive(int sd, int keepalive)
+int nepim_socket_keepalive(FILE *err, int sd, int keepalive)
 {
   if (keepalive == -1)
     return NEPIM_SOCK_ERR_NONE;
 
   if (setsockopt(sd, SOL_SOCKET, SO_KEEPALIVE,
 		 &keepalive, sizeof(keepalive))) {
-    int e = errno;
-    fprintf(stderr, "%s: %s: set socket keepalive: sd=%d: errno=%d: %s\n",
-	    __FILE__, __PRETTY_FUNCTION__,
-	    sd, e, strerror(e));
+
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: setsockopt: SO_KEEPALIVE: sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      sd, e, strerror(e));
+    }
+
     return NEPIM_SOCK_ERR_SOCK_KA;
   }
 
   return NEPIM_SOCK_ERR_NONE;
 }
 
-static int nepim_socket_get_keepalive(int sd)
+static int nepim_socket_get_keepalive(FILE *err, int sd)
 {
   int keepalive;
   socklen_t optlen = sizeof(keepalive);
 
   if (getsockopt(sd, SOL_SOCKET, SO_KEEPALIVE,
 		 &keepalive, &optlen)) {
-    int e = errno;
-    fprintf(stderr, "%s: %s: get socket keepalive: sd=%d: errno=%d: %s\n",
-	    __FILE__, __PRETTY_FUNCTION__,
-	    sd, e, strerror(e));
+
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: getsockopt: SO_KEEPALIVE: sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      sd, e, strerror(e));
+    }
+
     return NEPIM_SOCK_ERR_SOCK_KA;
   }
   
@@ -590,7 +675,8 @@ static int nepim_socket_get_keepalive(int sd)
   return keepalive;
 }
 
-int nepim_connect_client_socket(const struct sockaddr *bind, int bind_len,
+int nepim_connect_client_socket(FILE *err,
+				const struct sockaddr *bind, int bind_len,
 				struct sockaddr *addr, int addr_len,
 				int family,
 				int type,
@@ -606,7 +692,7 @@ int nepim_connect_client_socket(const struct sockaddr *bind, int bind_len,
   int sd;
   int result;
 
-  sd = nepim_create_socket(bind, bind_len,
+  sd = nepim_create_socket(err, bind, bind_len,
 			   family, type, protocol, pmtu_mode, ttl,
 			   0 /* mcast_join: false */,
 			   win_recv, win_send, nodelay, tos);
@@ -624,7 +710,7 @@ int nepim_connect_client_socket(const struct sockaddr *bind, int bind_len,
  }
 #endif /* Linux SO_BSDCOMPAT */
 
-  result = nepim_socket_keepalive(sd, socket_keepalive);
+  result = nepim_socket_keepalive(err, sd, socket_keepalive);
   if (result) {
     close(sd);
     return result;
@@ -641,20 +727,23 @@ int nepim_connect_client_socket(const struct sockaddr *bind, int bind_len,
 	  __FILE__, __PRETTY_FUNCTION__);
 
   if (connect(sd, addr, addr_len)) {
-    char buf[500];
-    int e = errno;
 
-    nepim_sock_dump_addr(buf, sizeof(buf), addr, addr_len);
+    if (err) {
+      char buf[500];
+      int e = errno;
 
-    if (family == PF_UNIX)
-      fprintf(stderr, "%s: %s: UNIX-socket connect(%d,%s): errno=%d: %s\n",
-	      __FILE__, __PRETTY_FUNCTION__,
-	      sd, buf, e, strerror(e));
-    else
-      fprintf(stderr, "%s: %s: connect(%d,%s,%d): errno=%d: %s\n",
-	      __FILE__, __PRETTY_FUNCTION__,
-	      sd, buf, nepim_sock_get_port(addr),
-	      e, strerror(e));
+      nepim_sock_dump_addr(buf, sizeof(buf), addr, addr_len);
+
+      if (family == PF_UNIX)
+	fprintf(err, "%s: %s: UNIX-socket connect(%d,%s): errno=%d: %s\n",
+		__FILE__, __PRETTY_FUNCTION__,
+		sd, buf, e, strerror(e));
+      else
+	fprintf(err, "%s: %s: connect(%d,%s,%d): errno=%d: %s\n",
+		__FILE__, __PRETTY_FUNCTION__,
+		sd, buf, nepim_sock_get_port(addr),
+		e, strerror(e));
+    }
     
     close(sd);
     return NEPIM_SOCK_ERR_CONNECT;
@@ -768,18 +857,19 @@ int nepim_socket_get_tos(int sd)
   return tos;
 }
 
-static int socket_get_mss(int sd)
+static int socket_get_mss(FILE *err, int sd)
 {
   int mss;
   socklen_t optlen = sizeof(mss);
 
   if (getsockopt(sd, SOL_TCP, TCP_MAXSEG, &mss, &optlen)) {
-#if 0
-    int e = errno;
-    fprintf(stderr, "%s: %s: get socket TCP_MAXSEG: sd=%d: errno=%d: %s\n",
-	    __FILE__, __PRETTY_FUNCTION__,
-	    sd, e, strerror(e));
-#endif
+
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: getsockopt: TCP_MAXSEG: sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      sd, e, strerror(e));
+    }
 
     return NEPIM_SOCK_ERR_MSS;
   }
@@ -789,7 +879,7 @@ static int socket_get_mss(int sd)
   return mss;
 }
 
-void nepim_sock_show_opt(FILE *out, int sd)
+void nepim_sock_show_opt(FILE *err, FILE *out, int sd)
 {
   int pmtud_mode;
   int mtu;
@@ -809,9 +899,9 @@ void nepim_sock_show_opt(FILE *out, int sd)
   win_recv = socket_get_win_recv(sd);
   win_send = socket_get_win_send(sd);
   tos = nepim_socket_get_tos(sd);
-  keepalive = nepim_socket_get_keepalive(sd);
-  nodelay = nepim_socket_get_nodelay(sd);
-  mss = socket_get_mss(sd);
+  keepalive = nepim_socket_get_keepalive(err, sd);
+  nodelay = nepim_socket_get_nodelay(err, sd);
+  mss = socket_get_mss(err, sd);
 
   fprintf(out, 
 	  "%d:"
