@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.75 2006/06/07 15:27:43 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.79 2006/08/15 13:20:33 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -188,10 +188,12 @@ static void udp_slot_start(nepim_slot_t *slot)
   else {
     if (session->keepalive_must_send) {
 
+#if 0
       fprintf(stderr, 
               "DEBUG %s %s: %d %d-%d: scheduling sending of keepalives\n",
               __FILE__, __PRETTY_FUNCTION__,
               slot->udp_sd, slot->index, slot->index_remote);
+#endif
       
       session->tv_keepalive_send_next = OOP_TIME_NOW;
       nepim_global.oop_src->on_time(nepim_global.oop_src,
@@ -496,7 +498,8 @@ static void *on_udp_interval(oop_source *src, struct timeval tv, void *user)
                   session->interval_writes,
 		  slot->seq_highest_recv - slot->interval_last_highest_seq,
                   slot->interval_pkt_lost,
-                  slot->interval_pkt_ooo);
+                  slot->interval_pkt_ooo,
+		  slot->total_pkt_lost);
 
   session->byte_interval_recv = 0;
   session->byte_interval_sent = 0;
@@ -554,7 +557,8 @@ static void *on_udp_duration(oop_source *src, struct timeval tv, void *user)
                   session->total_writes,
 		  slot->seq_highest_recv,
                   slot->total_pkt_lost,
-                  slot->total_pkt_ooo);
+                  slot->total_pkt_ooo,
+		  slot->total_pkt_lost);
 
   session->byte_total_recv = 0;
   session->byte_total_sent = 0;
@@ -1150,7 +1154,8 @@ static void *on_udp_time_greet(oop_source *src, struct timeval tv,
   return OOP_CONTINUE;
 }
 
-static int spawn_udp_connection(const struct sockaddr *bindaddr,
+static int spawn_udp_connection(const char *hostport,
+				const struct sockaddr *bindaddr,
 				int bindaddr_len,
 				const char *hostname,
                                 const char *portname,
@@ -1169,10 +1174,10 @@ static int spawn_udp_connection(const struct sockaddr *bindaddr,
   memset(&hints, 0, sizeof(hints));
 
   if (nepim_global.search_unix_socket) {
-    gai_lookup = stat(hostname, &stat_buf);
+    gai_lookup = stat(hostport, &stat_buf);
     if (gai_lookup)
       fprintf(stderr, "not a UNIX domain path: %s: errno=%d: %s\n",
-	      hostname, errno, strerror(errno));
+	      hostport, errno, strerror(errno));
   }
   else
     gai_lookup = -1;
@@ -1209,7 +1214,7 @@ static int spawn_udp_connection(const struct sockaddr *bindaddr,
       Unix socket
     */
     
-    int len = strlen(hostname);
+    int len = strlen(hostport);
     if (len >= (int) sizeof(un_sock_addr.sun_path)) {
       fprintf(stderr, "%s %s: unix socket path overly long: len=%d > max=%d\n",
 	      __FILE__, __PRETTY_FUNCTION__,
@@ -1220,7 +1225,7 @@ static int spawn_udp_connection(const struct sockaddr *bindaddr,
     memset(&un_sock_addr, 0, sizeof(un_sock_addr));
 
     un_sock_addr.sun_family = AF_UNIX;
-    strcpy(un_sock_addr.sun_path, hostname);
+    strcpy(un_sock_addr.sun_path, hostport);
 
     hints.ai_socktype = SOCK_DGRAM;
     hints.ai_protocol = 0;
@@ -1241,7 +1246,7 @@ static int spawn_udp_connection(const struct sockaddr *bindaddr,
     if (ai->ai_family == PF_UNIX)
       fprintf(stderr, 
 	      "UNIX datagram socket trying path=%s\n",
-	      hostname);
+	      hostport);
     else
       fprintf(stderr, 
 	      "UDP socket trying %s,%d\n",
@@ -1269,7 +1274,7 @@ static int spawn_udp_connection(const struct sockaddr *bindaddr,
       if (ai->ai_family == AF_UNIX)
 	fprintf(stderr, 
 		"could not connect UNIX datagram socket to path=%s: %d\n",
-		hostname, sd);
+		hostport, sd);
       else
 	fprintf(stderr, 
 		"could not connect UDP socket to %s,%d: %d\n",
@@ -1350,6 +1355,7 @@ static void parse_hosts(const char *host_list)
 
   /* scan host_list */
   for (j = 0; j < size; ++j) {
+    char hostport[100];
     char hostname[100];
     char *portname;
 
@@ -1361,6 +1367,8 @@ static void parse_hosts(const char *host_list)
       continue;
     }
 
+    strcpy(hostport, hostname); /* save original "host,port" */
+
     /* split host/port */
     if (addr_split_port(hostname, sizeof(hostname), &portname))
       portname = (char *) nepim_global.portname;
@@ -1376,7 +1384,8 @@ static void parse_hosts(const char *host_list)
       int sd;
       nepim_greet_t opt;
 
-      sd = spawn_udp_connection(bind_addr, bind_addr_len,
+      sd = spawn_udp_connection(hostport,
+				bind_addr, bind_addr_len,
 				hostname, portname, 
                                 (struct sockaddr *) &remote, 
                                 &remote_len);
