@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.101 2006/07/17 13:47:59 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.103 2006/08/15 13:20:33 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -82,7 +82,8 @@ static void *on_udp_interval(oop_source *src, struct timeval tv, void *user)
 		  session->interval_writes,
 		  slot->seq_highest_recv - slot->interval_last_highest_seq,
 		  slot->interval_pkt_lost,
-		  slot->interval_pkt_ooo);
+		  slot->interval_pkt_ooo,
+		  slot->total_pkt_lost);
 
   session->byte_interval_recv = 0;
   session->byte_interval_sent = 0;
@@ -144,7 +145,8 @@ static void *on_udp_duration(oop_source *src, struct timeval tv, void *user)
 		  session->total_writes,
 		  slot->seq_highest_recv,
 		  slot->total_pkt_lost,
-		  slot->total_pkt_ooo);
+		  slot->total_pkt_ooo,
+		  slot->total_pkt_lost);
 
   session->byte_total_recv = 0;
   session->byte_total_sent = 0;
@@ -667,10 +669,12 @@ static void udp_slot_start(int local_slot)
   else {
     if (session->keepalive_must_send) {
 
+#if 0
       fprintf(stderr, 
 	      "DEBUG %s %s: %d %d-%d: scheduling sending of keepalives\n",
 	      __FILE__, __PRETTY_FUNCTION__,
 	      slot->udp_sd, slot->index, slot->index_remote);
+#endif
       
       session->tv_keepalive_send_next = OOP_TIME_NOW;
       nepim_global.oop_src->on_time(nepim_global.oop_src,
